@@ -22,10 +22,16 @@ from devsecops_engine_tools.engine_core.src.domain.model.vulnerability_managemen
 from devsecops_engine_tools.engine_core.src.domain.model.gateway.sbom_manager import (
     SbomManagerGateway,
 )
+from devsecops_engine_tools.engine_core.src.domain.model.gateway.risk_score_gateway import (
+    RiskScoreGateway,
+)
 from devsecops_engine_tools.engine_core.src.domain.model.input_core import InputCore
 from devsecops_engine_tools.engine_core.src.domain.model.level_vulnerability import (
     LevelVulnerability,
 )
+from devsecops_engine_tools.engine_core.src.domain.model.level_priority import (
+    LevelPriority,
+)
 from devsecops_engine_tools.engine_core.src.domain.model.customs_exceptions import (
     ExceptionVulnerabilityManagement,
     ExceptionFindingsExcepted,
@@ -58,12 +64,14 @@ class HandleScan:
         devops_platform_gateway: DevopsPlatformGateway,
         remote_config_source_gateway: DevopsPlatformGateway,
         sbom_tool_gateway: SbomManagerGateway,
+        risk_score_gateway: RiskScoreGateway,
     ):
         self.vulnerability_management = vulnerability_management
         self.secrets_manager_gateway = secrets_manager_gateway
         self.devops_platform_gateway = devops_platform_gateway
         self.remote_config_source_gateway = remote_config_source_gateway
         self.sbom_tool_gateway = sbom_tool_gateway
+        self.risk_score_gateway = risk_score_gateway
 
     def process(self, dict_args: any, config_tool: any):
         secret_tool = None
@@ -85,6 +93,7 @@ class HandleScan:
             self._use_vulnerability_management(
                 config_tool, input_core, dict_args, secret_tool, env
             )
+            self.risk_score_gateway.get_risk_score(findings_list, config_tool, dict_args["module"])
             return findings_list, input_core
         elif "engine_container" in dict_args["module"]:
             findings_list, input_core, sbom_components = runner_engine_container(
@@ -102,6 +111,7 @@ class HandleScan:
                 env,
                 sbom_components,
             )
+            self.risk_score_gateway.get_risk_score(findings_list, config_tool, dict_args["module"])
             return findings_list, input_core
         elif "engine_function" in dict_args["module"]:
             findings_list, input_core = runner_engine_function(
@@ -118,6 +128,7 @@ class HandleScan:
                 secret_tool,
                 env
             )
+            self.risk_score_gateway.get_risk_score(findings_list, config_tool, dict_args["module"])
             return findings_list, input_core
         elif "engine_dast" in dict_args["module"]:
             findings_list, input_core = runner_engine_dast(
@@ -130,6 +141,7 @@ class HandleScan:
             self._use_vulnerability_management(
                 config_tool, input_core, dict_args, secret_tool, env
             )
+            self.risk_score_gateway.get_risk_score(findings_list, config_tool, dict_args["module"])
             return findings_list, input_core
         elif "engine_code" in dict_args["module"]:
             findings_list, input_core = runner_engine_code(
@@ -141,6 +153,7 @@ class HandleScan:
             self._use_vulnerability_management(
                 config_tool, input_core, dict_args, secret_tool, env
             )
+            self.risk_score_gateway.get_risk_score(findings_list, config_tool, dict_args["module"])
             return findings_list, input_core
         elif "engine_secret" in dict_args["module"]:
             findings_list, input_core = runner_secret_scan(
@@ -153,6 +166,7 @@ class HandleScan:
             self._use_vulnerability_management(
                 config_tool, input_core, dict_args, secret_tool, env
             )
+            self.risk_score_gateway.get_risk_score(findings_list, config_tool, dict_args["module"])
             return findings_list, input_core
         elif "engine_dependencies" in dict_args["module"]:
             findings_list, input_core, sbom_components = runner_engine_dependencies(
@@ -166,6 +180,7 @@ class HandleScan:
             self._use_vulnerability_management(
                 config_tool, input_core, dict_args, secret_tool, env, sbom_components
             )
+            self.risk_score_gateway.get_risk_score(findings_list, config_tool, dict_args["module"])
             return findings_list, input_core
 
     def _use_vulnerability_management(
@@ -279,7 +294,8 @@ class HandleScan:
                 )
                 if apply_qualitypt:
                     pt_info = apply_qualitypt[pt_name]
-                    pt_profile = pt_info["PROFILE"]
+                    pt_profile = pt_info["PROFILE"] if config_tool["BREAK_BUILD_MANAGER"]["MODEL"] == "severity" else None
+                    pt_profile_priority = pt_info["PROFILE_PRIORITY"] if config_tool["BREAK_BUILD_MANAGER"]["MODEL"] == "priority" else None
                     pt_apps = pt_info["APPS"]
 
                     input_core.threshold_defined.vulnerability = (
@@ -287,4 +303,10 @@ class HandleScan:
                         if pt_apps == "ALL"
                         or any(map(lambda pd: pd in input_core.scope_pipeline, pt_apps))
                         else input_core.threshold_defined.vulnerability
-                    )
+                    ) if pt_profile else input_core.threshold_defined.vulnerability
+                    input_core.threshold_defined.priority = (
+                        LevelPriority(quality_vulnerability_management[pt_profile_priority])
+                        if pt_apps == "ALL"
+                        or any(map(lambda pd: pd in input_core.scope_pipeline, pt_apps))
+                        else input_core.threshold_defined.priority
+                    ) if pt_profile_priority else input_core.threshold_defined.priority
