@@ -1,9 +1,6 @@
 from devsecops_engine_tools.engine_utilities.sonarqube.src.domain.usecases.report_sonar import (
     ReportSonar,
 )
-from devsecops_engine_tools.engine_utilities.utils.printers import (
-    Printers,
-)
 from devsecops_engine_tools.engine_core.src.domain.usecases.metrics_manager import (
     MetricsManager,
 )
@@ -18,21 +15,20 @@ def init_report_sonar(
     vulnerability_management_gateway,
     secrets_manager_gateway,
     devops_platform_gateway,
+    remote_config_source_gateway,
     sonar_gateway,
     metrics_manager_gateway,
     args,
 ):
-    config_tool = devops_platform_gateway.get_remote_config(
+    config_tool = remote_config_source_gateway.get_remote_config(
         args["remote_config_repo"], "/engine_core/ConfigTool.json", args["remote_config_branch"]
     )
-    report_config_tool = devops_platform_gateway.get_remote_config(
-        args["remote_config_repo"], "/report_sonar/ConfigTool.json", args["remote_config_branch"]
+    report_config_tool = remote_config_source_gateway.get_remote_config(
+        args["remote_config_repo"], "/engine_integrations/report_sonar/ConfigTool.json", args["remote_config_branch"]
     )
-    excluded_pipelines = devops_platform_gateway.get_remote_config(
-        args["remote_config_repo"], "/report_sonar/Exclusions.json", args["remote_config_branch"]
+    excluded_pipelines = remote_config_source_gateway.get_remote_config(
+        args["remote_config_repo"], "/engine_integrations/report_sonar/Exclusions.json", args["remote_config_branch"]
     )
-    
-    Printers.print_logo_tool(config_tool["BANNER"])
 
     pipeline_name = devops_platform_gateway.get_variable("pipeline_name")
     branch = devops_platform_gateway.get_variable("branch_tag")
@@ -61,6 +57,7 @@ def init_report_sonar(
             vulnerability_management_gateway,
             secrets_manager_gateway,
             devops_platform_gateway,
+            remote_config_source_gateway,
             sonar_gateway,
         ).process(args)
 
