@@ -28,30 +28,21 @@ class TrivyDeserializator(DeseralizatorGateway):
                 vulnerabilities = [
                     Finding(
                         id=vul.get("VulnerabilityID", ""),
-                        cvss=str(
-                            next(
-                                (
-                                    v["V3Score"]
-                                    for v in vul["CVSS"].values()
-                                    if "V3Score" in v
-                                ),
-                                None,
-                            )
-                        ) if vul.get("CVSS") else "",
+                        cvss=self._get_cvss_v3_score(vul.get("CVSS")),
                         where=vul.get("PkgName", "")
                         + ":"
                         + vul.get("InstalledVersion", ""),
                         description=vul.get("Description", "").replace("\n", "")[:150],
-                        severity=vul.get("Severity", "").lower(),
+                        severity=self._get_cvss_v3_severity(self._get_cvss_v3_score(vul.get("CVSS")), vul.get("Severity", "").lower()),
                         identification_date=datetime.now().strftime("%Y-%m-%dT%H:%M:%S%z"),
-                        published_date_cve=self._check_date_format(vul),
+                        published_date_cve=self._check_date_format(vul) if vul.get("PublishedDate") else None,
                         module=module,
                         category=Category.VULNERABILITY,
                         requirements=vul.get("FixedVersion") or vul.get("Status", ""),
                         tool="Trivy",
                     )
                     for vul in vulnerabilities_data
-                    if vul.get("PublishedDate")
+                    
                 ]
                 list_open_vulnerabilities.extend(vulnerabilities)
 
@@ -75,20 +66,13 @@ class TrivyDeserializator(DeseralizatorGateway):
                     cve_id=vul.get("VulnerabilityID", "unknown"),
                     cwe_id=vul.get("CweIDs", "unknown"),
                     vendor_id=vul.get("VendorIDs", "unknown"),
-                    severity=vul.get("Severity", "unknown").lower(),
+                    severity=self._get_cvss_v3_severity(self._get_cvss_v3_score(vul.get("CVSS")), vul.get("Severity", "unknown").lower()),
                     vulnerability_status=vul.get("Status", "unknown"),
                     target_image=result.get("Target", "unknown"),
                     package_name=vul.get("PkgName", "unknown"),
                     installed_version=vul.get("InstalledVersion", "unknown"),
                     fixed_version=vul.get("FixedVersion", "unknown"),
-                    cvss_score=next(
-                        (
-                            v.get("V3Score", "unknown")
-                            for v in vul.get("CVSS", {}).values()
-                            if "V3Score" in v
-                        ),
-                        None,
-                    ),
+                    cvss_score=self._get_cvss_v3_score(vul.get("CVSS")),
                     cvss_vector=vul.get("CVSS", "unknown"),
                     description=vul.get("Description", "unknown").replace("\n", ""),
                     os_type=result.get("Type", "unknown"),
@@ -130,4 +114,37 @@ class TrivyDeserializator(DeseralizatorGateway):
                 .replace(tzinfo=timezone.utc)
                 .isoformat()
             )
-        return published_date_cve
\ No newline at end of file
+        return published_date_cve
+
+    def _get_cvss_v3_severity(self, cvss_score: str, severity: str) -> str:
+        if not cvss_score:
+            severity
+            return severity
+        else:
+            try:
+                cvss_score = float(cvss_score)
+            except ValueError:
+                return severity
+            if cvss_score < 4.0:
+                return "low"
+            elif 4.0 <= cvss_score < 7.0:
+                return "medium"
+            elif 7.0 <= cvss_score < 9.0:
+                return "high"
+            elif cvss_score >= 9.0:
+                return "critical"
+    
+    def _get_cvss_v3_score(self, cvss_data: any) -> str:
+        if not cvss_data:
+            return ""
+        else:
+            return str(
+                next(
+                    (
+                        v["V3Score"]
+                        for v in cvss_data.values()
+                        if "V3Score" in v
+                    ),
+                    "",
+                )
+            )
\ No newline at end of file
